@@ -16,8 +16,8 @@ from chat_exporter.build_embed import BuildEmbed
 from chat_exporter.build_attachments import BuildAttachment
 from chat_exporter.build_reaction import BuildReaction
 from chat_exporter.build_html import fill_out, start_message, bot_tag, message_reference, message_reference_unknown, \
-    message_content, message_body, end_message, total, PARSE_MODE_NONE, PARSE_MODE_MARKDOWN, PARSE_MODE_REFERENCE
-
+    message_content, message_body, end_message, total, PARSE_MODE_NONE, PARSE_MODE_MARKDOWN, PARSE_MODE_REFERENCE, \
+    img_attachment
 from chat_exporter.parse_mention import pass_bot
 
 
@@ -97,6 +97,8 @@ class Transcript:
     @classmethod
     async def export(cls, channel: discord.TextChannel, limit, timezone_string: str = "Europe/London") -> "Transcript":
         messages = await channel.history(limit=limit, oldest_first=True).flatten()
+        if limit:
+            messages.reverse()
         transcript = await Transcript(channel=channel, guild=channel.guild, messages=messages,
                                       timezone_string=timezone(timezone_string))\
             .build_transcript()
@@ -173,6 +175,7 @@ class Message:
 
         await self.build_content()
         await self.build_reference()
+        await self.build_sticker()
 
         for e in self.message.embeds:
             self.embeds += await BuildEmbed(e, self.message.guild).flow()
@@ -213,7 +216,7 @@ class Message:
             self.message_html += await fill_out(self.message.guild, start_message, [
                 ("REFERENCE", self.message.reference, PARSE_MODE_NONE),
                 ("AVATAR_URL", str(self.message.author.avatar_url), PARSE_MODE_NONE),
-                ("NAME_TAG", "%s#%s" % (self.message.author.name, self.message.author.discriminator)),
+                ("NAME_TAG", "%s#%s" % (self.message.author.name, self.message.author.discriminator), PARSE_MODE_NONE),
                 ("USER_ID", str(self.message.author.id)),
                 ("USER_COLOUR", user_colour),
                 ("NAME", str(html.escape(self.message.author.display_name))),
@@ -235,6 +238,15 @@ class Message:
             ("EDIT", self.time_string_edit, PARSE_MODE_NONE)
         ])
 
+    async def build_sticker(self):
+        if not self.message.stickers or self.message.stickers[0].image_url is None:
+            return
+
+        self.message.content = await fill_out(self.message.guild, img_attachment, [
+            ("ATTACH_URL", str(self.message.stickers[0].image_url), PARSE_MODE_NONE),
+            ("ATTACH_URL_THUMB", str(self.message.stickers[0].image_url), PARSE_MODE_NONE)
+        ])
+
     async def build_reference(self):
         if not self.message.reference:
             self.message.reference = ""
@@ -243,7 +255,8 @@ class Message:
         try:
             message: discord.Message = await self.message.channel.fetch_message(self.message.reference.message_id)
         except discord.NotFound:
-            return message_reference_unknown
+            self.message.reference = message_reference_unknown
+            return
 
         is_bot = self.check_if_bot(message)
         user_colour = self.user_colour_translate(self.message.guild, message.author)
@@ -267,7 +280,7 @@ class Message:
         self.message.reference = await fill_out(self.message.guild, message_reference, [
             ("AVATAR_URL", str(message.author.avatar_url), PARSE_MODE_NONE),
             ("BOT_TAG", is_bot, PARSE_MODE_NONE),
-            ("NAME_TAG", "%s#%s" % (message.author.name, message.author.discriminator)),
+            ("NAME_TAG", "%s#%s" % (message.author.name, message.author.discriminator), PARSE_MODE_NONE),
             ("NAME", str(html.escape(message.author.display_name))),
             ("USER_COLOUR", user_colour, PARSE_MODE_NONE),
             ("CONTENT", message.content, PARSE_MODE_REFERENCE),
